@@ -6,8 +6,10 @@ use Pcore;
 use Pcore::Util::CA;
 use Pcore::Util::Host;
 
-Pcore::Util::CA::update() or exit 3;
+Pcore::Util::CA::update()     or exit 3;
 Pcore::Util::Host->update_all or exit 3;
+P->mime->update               or exit 3;
+P->result->update             or exit 3;
 
 1;
 __END__
